@@ -392,7 +392,7 @@ class BrowserView(QMainWindow):
                  height=default_window_height,
                  resizable=True, full_screen=False, min_size=(min_window_width, min_window_height),
                  background_color="#ffffff", web_view_ready=None, cid='', enable_max=True, window_type='cef',
-                 quit_app_when_main_window_close=True, popup_validate=None,extendScreen="false"):
+                 quit_app_when_main_window_close=True, popup_validate=None, extendScreen="false"):
         super(BrowserView, self).__init__()
         BrowserView.instances[uid] = self
         screen = QDesktopWidget().screenGeometry()
@@ -423,7 +423,11 @@ class BrowserView(QMainWindow):
         # 处理默认窗口大小
         if width != -1 and height != -1:
             if extendScreen == "true":
-                self.resize(screen_width, screen_height)
+                if QDesktopWidget().screenCount() > 1:
+                    screen1 = QDesktopWidget().screenGeometry(1)
+                    self.resize(screen1.width(), screen1.height())
+                else:
+                    self.resize(screen_width, screen_height)
             else:
                 self.resize(width, height)
         else:
@@ -447,7 +451,7 @@ class BrowserView(QMainWindow):
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.setWindowFlags(Qt.CustomizeWindowHint | Qt.WindowMinMaxButtonsHint | Qt.WindowCloseButtonHint)
         # 禁用窗口最大化
-        if not enable_max  and extendScreen=="false":
+        if not enable_max and extendScreen == "false":
             self.setFixedSize(self.width(), self.height())
             self.setWindowFlags(Qt.CustomizeWindowHint | Qt.WindowMinimizeButtonHint | Qt.WindowCloseButtonHint)
 
@@ -619,10 +623,10 @@ class BrowserView(QMainWindow):
             param.setdefault('width', default_window_width)
             param.setdefault('height', default_window_height)
             param.setdefault('enableMax', True)
-            param.setdefault('extendScreen','false')
+            param.setdefault('extendScreen', 'false')
             open_new_window(url=param["url"], title=param["title"], payload=param["payload"],
                             maximized=param["maximized"], minimized=param["minimized"], cid=param["cid"],
-                            width=param["width"], height=param["height"], enable_max=param["enableMax"],extendScreen=param["extendScreen"])
+                            width=param["width"], height=param["height"], enable_max=param["enableMax"], extendScreen=param["extendScreen"])
         elif isinstance(param, str):
             open_new_window(url=param)
 
@@ -777,6 +781,16 @@ class BrowserView(QMainWindow):
         logging.debug('[Nest Frame Window] : param = {param}'.format(param=param))
         if param is None:
             param = {}
+
+        try:
+            # 外置浏览器打开时，要拼接参数
+            if param.get("open_default_browser", "false") == "true" and param.get('url') and param.get(
+                    "sip_appkey") and param.get("sip_sign"):
+                param["url"] = str(param["url"]) + "&sip_appkey=" + str(param.get("sip_appkey")) + "&sip_sign=" + str(
+                    param.get("sip_sign"))
+        except Exception as e:
+            logging.error("外置浏览器打开链接，拼接参数错误：" + str(e))
+
         if isinstance(param, dict):
             param.setdefault('newCid', '')  # 新窗口的cid
             param.setdefault('targetCid', 'master')  # 目标窗口cid
@@ -787,27 +801,36 @@ class BrowserView(QMainWindow):
             param.setdefault('bottom', default_nest_window_margin)  # 内嵌窗口距离target窗口的底部距离
             param.setdefault('left', default_nest_window_margin)  # 内嵌窗口距离target窗口的左侧距离
             param.setdefault('windowType', 'cef')
-            frame_window = create_qt_view(url=param['url'], cid=param['newCid'], default_show=False,
-                                          payload=param['payload'], window_type=param['windowType'],
-                                          popup_validate=self.popup_validate)
-            frame_window.responsive_params['top'] = param['top']
-            frame_window.responsive_params['right'] = param['right']
-            frame_window.responsive_params['bottom'] = param['bottom']
-            frame_window.responsive_params['left'] = param['left']
-            target_uid = self.get_uid_by_cid(param['targetCid'])
-            if target_uid is not None:
-                global pixel_ratio
-                if platform.system() == 'Windows':
-                    pixel_ratio = dpi_dict[str(frame_window.logicalDpiX())]
-                target_window = BrowserView.instances[target_uid]
-                target_window.attached_child_list.append(frame_window)
-                frame_window.setParent(target_window)
-                frame_window.show()
-                frame_window.move(param['left'] * pixel_ratio, param['top'] * pixel_ratio)
-                width = target_window.width() - param['left'] * pixel_ratio - param['right'] * pixel_ratio
-                height = target_window.height() - param['top'] * pixel_ratio - param['bottom'] * pixel_ratio
-                frame_window.resize(width, height)
-                frame_window.setWindowFlags(Qt.FramelessWindowHint)
+            param.setdefault('open_default_browser', 'false')        #是否使用外置默认浏览器打开界面 true 使用，false 不使用
+
+
+            if param.get("open_default_browser") == "true":
+                try:
+                    webbrowser.open(param.get("url"))
+                except Exception as e:
+                    logging.error("外置浏览器打开异常，检查是否存在默认浏览器；异常原因："+e.__str__())
+            else:
+                frame_window = create_qt_view(url=param['url'], cid=param['newCid'], default_show=False,
+                                              payload=param['payload'], window_type=param['windowType'],
+                                              popup_validate=self.popup_validate)
+                frame_window.responsive_params['top'] = param['top']
+                frame_window.responsive_params['right'] = param['right']
+                frame_window.responsive_params['bottom'] = param['bottom']
+                frame_window.responsive_params['left'] = param['left']
+                target_uid = self.get_uid_by_cid(param['targetCid'])
+                if target_uid is not None:
+                    global pixel_ratio
+                    if platform.system() == 'Windows':
+                        pixel_ratio = dpi_dict[str(frame_window.logicalDpiX())]
+                    target_window = BrowserView.instances[target_uid]
+                    target_window.attached_child_list.append(frame_window)
+                    frame_window.setParent(target_window)
+                    frame_window.show()
+                    frame_window.move(param['left'] * pixel_ratio, param['top'] * pixel_ratio)
+                    width = target_window.width() - param['left'] * pixel_ratio - param['right'] * pixel_ratio
+                    height = target_window.height() - param['top'] * pixel_ratio - param['bottom'] * pixel_ratio
+                    frame_window.resize(width, height)
+                    frame_window.setWindowFlags(Qt.FramelessWindowHint)
 
     def update_window_geometry(self, cid=None):
         if cid is None:
@@ -1162,11 +1185,11 @@ def generate_guid(prefix='child'):
 
 
 def open_new_window(url, title=default_window_title, payload=None, maximized=False, minimized=False, cid='',
-                    width=default_window_width, height=default_window_height, enable_max=True,extendScreen="false"):
+                    width=default_window_width, height=default_window_height, enable_max=True, extendScreen="false"):
     logging.debug('[Open New Window] : url={url}, cid={cid}'.format(url=url, cid=cid))
     create_browser_view(uid=generate_guid(), url=url, title=title, payload=payload, maximized=maximized,
                         minimized=minimized, cid=cid, width=width, height=height, enable_max=enable_max,
-                        inject_obj=app_inject_obj, application_version=app_version_info,extend_Screen=extendScreen)
+                        inject_obj=app_inject_obj, application_version=app_version_info, extend_Screen=extendScreen)
 
 
 def create_qt_view(default_show=True, window_type='cef', url='', cid='', payload={}, popup_validate=None):
@@ -1213,15 +1236,15 @@ def create_browser_view(uid, title="", url=None, width=default_window_width, hei
                         background_color="#ffffff", web_view_ready=None, payload=None, maximized=False,
                         minimized=False, cid='', call_back=None, enable_max=True, inject_obj=app_inject_obj,
                         quit_app_when_main_window_close=True, application_version=app_version_info,
-                        popup_validate=None,extend_Screen="false"):
+                        popup_validate=None, extend_Screen="false"):
     browser = BrowserView(uid, title, url, width, height, resizable, full_screen, min_size,
                           background_color, web_view_ready, cid=cid, enable_max=enable_max,
                           quit_app_when_main_window_close=quit_app_when_main_window_close,
-                          popup_validate=popup_validate,extendScreen=extend_Screen)
-    if maximized  and extend_Screen=='false':
+                          popup_validate=popup_validate, extendScreen=extend_Screen)
+    if maximized and extend_Screen == 'false':
         browser.showMaximized()
 
-    if minimized  and extend_Screen=='false':
+    if minimized and extend_Screen == 'false':
         browser.showMinimized()
 
     browser.show()
@@ -1274,7 +1297,7 @@ def launch_main_window(uid, title, url, width, height, resizable, full_screen, m
         exit_python()
         return
 
-    # show splash 启动界面控制
+    # show splash 启动界面控制  --在主浏览器窗口弹出前，弹出启动加载提示窗口
     if splash_screen:
         global splash
         splash = QSplashScreen()
@@ -1309,6 +1332,45 @@ def launch_main_window(uid, title, url, width, height, resizable, full_screen, m
         'disable-gpu-compositing': ''
     }
 
+    framework_dir_path = ""
+    browser_subprocess_path = ""
+    # 发布mac包用到的
+    if platform.system() == 'Darwin':
+        # 获取当前python的版本号
+        python_version = str(sys.version_info.major) + "." + str(sys.version_info.minor)
+
+        # framework_dir_path路径获取 研发模式和打包后的APP路径不一致
+        # 研发模式下，venv目录下的路径
+        framework_dir_path_venv = os.path.abspath("./venv/lib/python" + python_version + "/site-packages/cefpython3/Chromium Embedded Framework.framework")
+        browser_subprocess_path_venv = os.path.abspath("./venv/lib/python" + python_version + "/site-packages/cefpython3/subprocess")
+        exist_venv = os.path.exists(framework_dir_path_venv)
+
+        # APP 生产编译模式下，Contents/Resources下的路径
+        framework_dir_path_app = os.path.abspath("./lib/python" + python_version + "/cefpython3/Chromium Embedded Framework.framework")
+        browser_subprocess_path_app = os.path.abspath("./lib/python" + python_version + "/cefpython3/subprocess")
+        exist_app = os.path.exists(framework_dir_path_app)
+
+        # py2app 本地编译打包 -A 参数控制的alias模式下，应使用系统环境路径
+        framework_dir_path_system = os.path.abspath(sys.base_prefix + "/lib/python" + python_version + "/site-packages/cefpython3/Chromium Embedded Framework.framework")
+        browser_subprocess_path_system = os.path.abspath(sys.base_prefix + "/lib/python" + python_version + "/site-packages/cefpython3/subprocess")
+        exist_system = os.path.exists(framework_dir_path_system)
+
+        if exist_app:
+            framework_dir_path = framework_dir_path_app
+            browser_subprocess_path = browser_subprocess_path_app
+        elif exist_system:
+            framework_dir_path = framework_dir_path_system
+            browser_subprocess_path = browser_subprocess_path_system
+        else:
+            framework_dir_path = framework_dir_path_venv
+            browser_subprocess_path = browser_subprocess_path_venv
+
+        print("framework_dir_path : ", framework_dir_path)
+        print("browser_subprocess_path : ", browser_subprocess_path)
+
+        settings["framework_dir_path"] = framework_dir_path
+        settings["browser_subprocess_path"] = browser_subprocess_path
+
     cef.Initialize(settings=settings, switches=switches)
     create_browser_view(uid=uid, title=title, url=url, width=width, height=height, resizable=resizable,
                         full_screen=full_screen, min_size=min_size,
